'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.matchImageSnapshotCommand = matchImageSnapshotCommand;
exports.addMatchImageSnapshotCommand = addMatchImageSnapshotCommand;

var _lodash = require('lodash.kebabcase');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Copyright (c) 2018-present The Palmer Group
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            *
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

const screenshotsFolder = Cypress.config('screenshotsFolder');
const fileServerFolder = Cypress.config('fileServerFolder');
const updateSnapshots = Cypress.config('updateSnapshots') || false;

const defaultFileNameTransform = (name = '', test) => (0, _lodash2.default)(`${test.parent.title}-${test.title}-${name}`);

function matchImageSnapshotCommand(defaultOptions) {
  return (() => {
    var _ref = _asyncToGenerator(function* (subject, name, commandOptions) {
      const options = _extends({}, defaultOptions, (typeof name === 'string' ? commandOptions : name) || {});

      const { fileNameTransform = defaultFileNameTransform } = options;
      const fileName = fileNameTransform(name, this.test);
      const target = subject ? subject : cy;
      target.screenshot(fileName, options);

      const {
        pass,
        added,
        updated,
        diffRatio,
        diffPixelCount,
        diffOutputPath
      } = yield cy.task('matchImageSnapshot', {
        fileName,
        screenshotsFolder,
        fileServerFolder,
        updateSnapshots,
        options
      });

      const differencePercentage = diffRatio * 100;
      if (!pass && !added && !updated) {
        throw new Error(`Screenshot was ${differencePercentage}% different from saved snapshot with ${diffPixelCount} different pixels.\n  See diff for details: ${diffOutputPath}`);
      }
    });

    function matchImageSnapshot(_x, _x2, _x3) {
      return _ref.apply(this, arguments);
    }

    return matchImageSnapshot;
  })();
}

function addMatchImageSnapshotCommand(name = 'matchImageSnapshot', options) {
  const defaultOptions = typeof name === 'string' ? options : name;
  Cypress.Commands.add(name, matchImageSnapshotCommand(defaultOptions), {
    prevSubject: 'optional'
  });
}